%global __provides_exclude_from ^%{python3_sitearch}/.*\\.so$
%define modname gevent
%global optflags %(echo %{optflags} -I%{_includedir}/libev)

# with fixes from
# https://github.com/pld-linux/python-gevent/blob/master/python-gevent.spec

Name:		python-%{modname}
Version:	21.12.0
Release:	%mkrel 1
Summary:	A coroutine-based Python networking library
License:	MIT
Group:		Development/Python
Url:		https://www.gevent.org/
Source0:	https://pypi.io/packages/source/g/%{modname}/%{modname}-%{version}.tar.gz

BuildRequires: pyproject-rpm-macros
BuildRequires:	glibc-devel
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(libuv)

# Needed for tests
BuildRequires:  lsof
%{?with_system_libev:BuildRequires:    c-ares-devel >= 1.10.0}
%{?with_system_c_ares:BuildRequires:   libev-devel >= 4.11}
%{?with_tests:BuildRequires: python-greenlet}

%description
Gevent is a coroutine-based Python networking library that uses greenlet to
provide a high-level synchronous API on top of the libevent event loop.

%package -n python3-%{modname}
Summary: A coroutine-based Python3 networking library
Requires:   python3dist(greenlet)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-cython
BuildRequires:  python3dist(cffi)
BuildRequires:  python3dist(greenlet)
BuildRequires:  python3dist(setuptools)
%{?python_provide:%python_provide python3-%{modname}}

%description -n python3-%{modname}
Gevent is a coroutine-based Python3 networking library that uses greenlet to
provide a high-level synchronous API on top of the libevent event loop.

%prep
%autosetup -n %{modname}-%{version}
# Remove bundled libraries
rm -r deps
# Upstream intentionally includes C extension sources in the built package,
# because... reasons (PyPy I think?) however we do not want that. Sources will
# go into debuginfo as normal.
sed -i -e 's/include_package_data=True/include_package_data=False/' setup.py

# Force re-cythonizing the sources
rm $(grep -rl '/\* Generated by Cython')

%build
export GEVENTSETUP_EMBED=0
%pyproject_wheel

%install
export GEVENTSETUP_EMBED=0
%pyproject_install

rm %{buildroot}%{python3_sitearch}/%{modname}/_*2.py
rm %{buildroot}%{python3_sitearch}/%{modname}/__pycache__/_*2.*
find %{buildroot} -name '.buildinfo' -delete
# Correct the permissions.
find %{buildroot} -name '*.so' -exec chmod 755 {} ';'

%files -n python3-%{modname}
%license LICENSE
%doc README.rst
%{python3_sitearch}/%{modname}*


%changelog
* Thu Sep 29 2022 neoclust <neoclust> 21.12.0-1.mga9
+ Revision: 1893333
- New version 	21.12.0

* Mon Mar 28 2022 umeabot <umeabot> 21.1.2-3.mga9
+ Revision: 1829528
- Mageia 9 Mass Rebuild

* Tue Feb 15 2022 tv <tv> 21.1.2-2.mga9
+ Revision: 1775498
- Force re-cythonizing the sources (remove Cython generated .c files)
- Use updated build variables
- Rebuild for python-3.10

* Sun Apr 04 2021 joequant <joequant> 21.1.2-1.mga9
+ Revision: 1713254
- update to 21.1.2

* Sun Feb 16 2020 umeabot <umeabot> 1.4.0-3.mga8
+ Revision: 1532715
- Mageia 8 Mass Rebuild

* Tue Sep 17 2019 tv <tv> 1.4.0-2.mga8
+ Revision: 1442866
- rebuild for python-3.8
- drop python2 subpkg

* Wed Jan 09 2019 shlomif <shlomif> 1.4.0-1.mga7
+ Revision: 1353157
- Rebuild for python3 3.7

* Tue Jan 08 2019 tv <tv> 1.3.6-1.mga7
+ Revision: 1352255
- new release
- rebuild with python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 1.2.2-3.mga7
+ Revision: 1300485
- Mageia 7 Mass Rebuild

* Mon Apr 16 2018 kekepower <kekepower> 1.2.2-2.mga7
+ Revision: 1219167
- Fix BRs
- Use python_provide
- Create and use py3dir

* Mon Sep 11 2017 joequant <joequant> 1.2.2-1.mga7
+ Revision: 1152961
- fix build
- update to 1.2.2 - previous version fails with python 3.6
  see https://github.com/gevent/gevent/issues/903

* Sat Aug 05 2017 pterjan <pterjan> 1.1.1-2.mga7
+ Revision: 1135432
- Rebuild for python 3.6

* Tue Apr 26 2016 joequant <joequant> 1.1.1-1.mga6
+ Revision: 1006312
- upgrade to 1.1.1

* Fri Feb 12 2016 umeabot <umeabot> 1.1b5-3.mga6
+ Revision: 958598
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 joequant <joequant> 1.1b5-2.mga6
+ Revision: 887390
- upgrade to python 3.5

* Sun Sep 27 2015 joequant <joequant> 1.1b5-1.mga6
+ Revision: 884183
- update to 1.1b5

* Thu Sep 17 2015 joequant <joequant> 1.1b4-3.mga6
+ Revision: 880022
- bump version
- add with_tests check
- remove test
- refresh build
- add failure
- add urllib2 test to known failures
- update to 1.1b4
- add greenlet requires for tests
- upgrade to 1.1b1 with python3
- upgrade to 1.0.1

* Thu Jan 08 2015 joequant <joequant> 0.13.8-9.mga5
+ Revision: 809280
- python3 fixes

* Wed Oct 29 2014 joequant <joequant> 0.13.8-8.mga5
+ Revision: 794472
- revert to old version with 2to3 and requires fixes
- python2 package was including python3
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps

* Fri Sep 12 2014 joequant <joequant> 1.0.1-1.mga5
+ Revision: 674845
- update to 1.0.1 - previous version broken with python update

* Wed Sep 10 2014 bcornec <bcornec> 0.13.8-7.mga5
+ Revision: 674556
- make python-gevent python 3 compatible
+ pterjan <pterjan>
- Rebuild for new Python

* Wed Oct 23 2013 philippem <philippem> 0.13.8-5.mga4
+ Revision: 546532
- fix pythonegg

* Tue Oct 22 2013 umeabot <umeabot> 0.13.8-4.mga4
+ Revision: 543615
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.13.8-3.mga4
+ Revision: 498670
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Jan 13 2013 umeabot <umeabot> 0.13.8-2.mga3
+ Revision: 378892
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 26 2012 obgr_seneca <obgr_seneca> 0.13.8-1.mga3
+ Revision: 298233
- New version

* Sat Aug 25 2012 obgr_seneca <obgr_seneca> 0.13.7-4.mga3
+ Revision: 283889
- Rebuild for new python-greenlet

* Fri Jul 13 2012 obgr_seneca <obgr_seneca> 0.13.7-3.mga3
+ Revision: 270559
- Added missing require for python-greenlet

* Tue Jul 03 2012 obgr_seneca <obgr_seneca> 0.13.7-2.mga3
+ Revision: 266927
- rebuild against new libevent

* Tue May 29 2012 obgr_seneca <obgr_seneca> 0.13.7-1.mga3
+ Revision: 249191
- new version 0.13.7

* Mon Mar 12 2012 obgr_seneca <obgr_seneca> 0.13.6-1.mga2
+ Revision: 222990
- imported package python-gevent


* Fri Mar 09 2012 Oliver Burger <obgr_seneca@mageia.org> 0.13.6-1.mga2
- initial package for Mageia
